@@ -1,3 +1,4 @@
+from oarepo_model_builder.utils.jinja import split_package_base_name
 from ..builders import OutputBuilder
 from ..outputs.cfg import CFGOutput
 
@@ -10,7 +11,7 @@ class InvenioCliSetupCfgBuilder(OutputBuilder):
 
         output: CFGOutput = self.builder.get_output("cfg", "setup.cfg")
 
-        cli_function = self.settings.python.cli_function.rsplit(".", maxsplit=1)
+        cli_function = split_package_base_name(self.settings.python.cli_function)
 
         output.add_entry_point(
             "flask.commands",
