@@ -2,6 +2,8 @@ import os
 from pathlib import Path
 from typing import Dict
 
+from oarepo_model_builder.utils.jinja import split_base_name
+
 from ..schema import ModelSchema
 from . import ModelPreprocessor
 
@@ -13,7 +15,9 @@ class DefaultValuesModelPreprocessor(ModelPreprocessor):
         self.set(
             settings,
             "package",
-            lambda: os.path.basename(schema.schema.get("output-directory", os.getcwd())).replace("-", "_"),
+            lambda: os.path.basename(
+                schema.schema.get("output-directory", os.getcwd())
+            ).replace("-", "_"),
         )
 
         self.set(settings, "processing-order", lambda: ["settings", "*", "model"])
@@ -21,7 +25,7 @@ class DefaultValuesModelPreprocessor(ModelPreprocessor):
         self.set(
             settings,
             "package-base",
-            lambda: settings.package.rsplit(".", maxsplit=1)[-1],
+            lambda: split_base_name(settings.package),
         )
 
         self.set(settings, "package-base-upper", lambda: settings.package_base.upper())
@@ -33,7 +37,9 @@ class DefaultValuesModelPreprocessor(ModelPreprocessor):
             package_path = settings.package.split(".")
             return Path(package_path[0]).joinpath(*package_path[1:])
 
-        self.set(settings, "schema-version", lambda: schema.schema.get("version", "1.0.0"))
+        self.set(
+            settings, "schema-version", lambda: schema.schema.get("version", "1.0.0")
+        )
 
         self.set(
             settings,
@@ -44,10 +50,14 @@ class DefaultValuesModelPreprocessor(ModelPreprocessor):
         self.set(
             settings,
             "schema-file",
-            lambda: os.path.join(settings.package_path, "records", "jsonschemas", settings.schema_name),
+            lambda: os.path.join(
+                settings.package_path, "records", "jsonschemas", settings.schema_name
+            ),
         )
 
-        self.set(settings, "mapping-package", lambda: f"{settings.package}.records.mappings")
+        self.set(
+            settings, "mapping-package", lambda: f"{settings.package}.records.mappings"
+        )
 
         self.set(
             settings,
@@ -62,8 +72,8 @@ class DefaultValuesModelPreprocessor(ModelPreprocessor):
                 settings.package_path,
                 "records",
                 "mappings",
-                "v7",
-                settings.package_base,
+                "os-v2",
+                settings.package,
                 settings.schema_name,
             ),
         )
@@ -73,7 +83,22 @@ class DefaultValuesModelPreprocessor(ModelPreprocessor):
         self.set(
             settings,
             "index-name",
-            lambda: settings.package_base + "-" + os.path.basename(settings.mapping_file).replace(".json", ""),
+            lambda: settings.package
+            + "-"
+            + os.path.basename(settings.mapping_file).replace(".json", ""),
         )
 
-        self.set(settings, "collection-url", lambda: f"/{settings.package_base}/")
+        self.set(settings, "collection-url", lambda: f"/{settings.kebap_package}/")
+        self.set(settings, "model-name", lambda: settings.package_base)
+
+        # for outputting the model
+        self.set(
+            settings,
+            "saved-model-file",
+            lambda: settings.package_path / "models" / "model.json",
+        )
+        self.set(
+            settings,
+            "inherited-model-file",
+            lambda: settings.package_path / "models" / "inherited_model.json",
+        )
