@@ -6,9 +6,12 @@ from jinja2 import Environment, FunctionLoader, pass_context
 from oarepo_model_builder.outputs import OutputBase
 from oarepo_model_builder.templates import templates
 from oarepo_model_builder.utils.cst import PythonContext, merge
-from oarepo_model_builder.utils.jinja import (base_name, in_different_package,
-                                              package_name,
-                                              with_defined_prefix)
+from oarepo_model_builder.utils.jinja import (
+    base_name,
+    in_different_package,
+    package_name,
+    with_defined_prefix,
+)
 from oarepo_model_builder.utils.verbose import log
 
 
@@ -63,7 +66,7 @@ class PythonOutput(OutputBase):
         try:
             rendered = env.get_template(template_name).render(context)
         except Exception as exc:
-            raise Exception(f"Error rendering template {template_name}") from exc
+            raise RuntimeError(f"Error rendering template {template_name}") from exc
         try:
             rendered_cst = cst.parse_module(
                 rendered, config=self.cst.config_for_parsing
